@@ -26,20 +26,17 @@ import sys
 import tempfile
 import time
 from pathlib import Path
-from urllib.parse import urljoin, urlparse, urlunparse
+from typing import Iterable, List, Tuple, Union
 from urllib.parse import ParseResult as URL
-from typing import Iterable
-from typing import List
-from typing import Tuple
-from typing import Union
+from urllib.parse import urljoin, urlparse, urlunparse
 
 NAME = "jsbuild"
 VERSION = "0.0.1"
 
 # Logging
 
-log_format = "%(asctime)s %(levelname)s %(message)s"
-logging.basicConfig(level=logging.INFO, format=log_format)
+LOG_FORMAT = "%(asctime)s %(levelname)s %(message)s"
+logging.basicConfig(level=logging.INFO, format=LOG_FORMAT)
 logger = logging.getLogger(NAME)
 
 
@@ -96,7 +93,7 @@ def http_cache_or_download(url: str) -> str:
     except Exception:
         pass
 
-    logger.info(f"Downloading {url}...")
+    logger.info("Downloading %s...", url)
     subprocess.run(["curl", "--user-agent", USER_AGENT, "-o", path, "-s", url])
     return path.read_bytes().decode("utf-8")
 
@@ -117,7 +114,7 @@ def read_file_http(url: URL) -> str:
 
 
 def read_file(url: URL) -> str:
-    logger.debug(f"Reading {urlunparse(url)}...")
+    logger.debug("Reading %s...", urlunparse(url))
     scheme = url.scheme
     handler_name = f"read_file_{scheme}"
 
@@ -138,10 +135,10 @@ def resolve_absolute(current: str, new: str) -> URL:
 
 # Closure compiler URL
 
-ver = "v20221004"
+VER = "v20230206"
 REPO = "https://repo1.maven.org/maven2"
 PROJECT = "com/google/javascript/closure-compiler"
-CLOSURE_URL = f"{REPO}/{PROJECT}/{ver}/closure-compiler-{ver}.jar"
+CLOSURE_URL = f"{REPO}/{PROJECT}/{VER}/closure-compiler-{VER}.jar"
 CLOSURE = cache_path(CLOSURE_URL)
 
 
@@ -159,7 +156,19 @@ def java_check():
         sys.exit(1)
 
 
-def closure_compile(path: Path):
+def closure_compile(path: Path) -> str:
+    """Compile a given file with the Closure compiler.
+
+    Parameters
+    ----------
+    path : Path
+        The path to the file to compile.
+
+    Returns
+    -------
+    str
+        The contents of the compiled file.
+    """
     java_check()  # Make sure Java is installed.
 
     params: List[Union[str, Path]] = []
@@ -187,6 +196,8 @@ def closure_compile(path: Path):
     # Output
     params.append("--language_out")
     params.append(ARGS.language_out)
+    params.append("--js_output_file")
+    params.append("output.js")
 
     # Entry point
     params.append("--js")
@@ -197,8 +208,8 @@ def closure_compile(path: Path):
     proc = subprocess.run(params, cwd=path, capture_output=True)
 
     for err_line in proc.stderr.decode("utf-8").splitlines():
-        logger.warning(f"[closure] {err_line.strip()}")
-    return proc.stdout.decode("utf-8").strip().replace("\n", "")
+        logger.warning("[closure] %s", err_line.strip())
+    return (Path(path) / "output.js").read_text().strip()
 
 
 # Deps
@@ -228,8 +239,7 @@ def patch_import_statement(
         h = hash_buffer(url)
         if inside_import:
             return f'import {m.group(1)} from "./{h}.js";'
-        else:
-            return f'import {m.group(1)} from "./imports/{h}.js";'
+        return f'import {m.group(1)} from "./imports/{h}.js";'
     return line
 
 
@@ -245,9 +255,9 @@ def patch_import_statement(
 
 
 def action_list_deps():
-    """Prints the list of dependencies that are included by your program. Note
-    that the output of this command includes the dependencies recursively.
+    """Print the list of dependencies that are included by your program.
 
+    Note that the output of this command includes the dependencies recursively.
     """
     path = Path(ARGS.file)
 
@@ -263,11 +273,14 @@ def action_list_deps():
 
 
 def action_dependency_dag():
-    """Draws a Directed Acyclic Graph of the dependency tree.
+    """Draw a Directed Acyclic Graph of the dependency tree.
 
     This requires `Graphviz` to generate the tree image and `feh` to display it
     on the screen.
 
+    Notes
+    -----
+    This command needs graphviz and feh to be installed on your system.
     """
     path = Path(ARGS.file).resolve()
     url = f"file://{path}"
@@ -324,21 +337,20 @@ def action_dependency_dag():
 
 
 def action_ensure_closure():
-    """
-    Downloads or updates the Closure compiler.
-    """
+    """Download or update the Closure compiler."""
     subprocess.run(["curl", "-o", cache_path(CLOSURE_URL), CLOSURE_URL])
 
 
 def action_build():
-    """Fetches all the dependencies of the input file and builds it."""
+    """Fetch all the dependencies of the input file and build it."""
     path = Path(ARGS.file).resolve()
 
     with (TEMPDIR / "main.js").open("w+") as main_file:
-        for line in path.open("r"):
-            main_file.write(
-                patch_import_statement(line, f"file://{path}") + "\n"
-            )
+        with path.open("r") as f:
+            for line in f:
+                main_file.write(
+                    patch_import_statement(line, f"file://{path}") + "\n"
+                )
 
     os.makedirs(TEMPDIR / "imports")
     imports: set[URL] = set()
@@ -373,8 +385,7 @@ def action_build():
 
 
 def action_nuke_cache():
-    """Deletes the cached files."""
-
+    """Delete the cached files."""
     print("Deleting cached files...")
 
     # Do not remove the cache directory itself, just its contents.
@@ -437,7 +448,7 @@ def doctor_check_closure_version():
 
 
 def action_doctor():
-    """Checks if the environment is ready to run the tool."""
+    """Check if the environment is ready to run the tool."""
     print("Welcome to the doctor!")
     print("")
     print("This tool will check if your environment is ready to run the tool.")
@@ -469,7 +480,9 @@ def action_doctor():
                 else:
                     print("ERROR (run with --verbose for more info)")
             end_time = time.monotonic()
-            logger.debug(f"Check {name} took {end_time - start_time} seconds")
+            logger.debug(
+                "Check %s took %s seconds", name, end_time - start_time
+            )
 
 
 # Command-line arguments
@@ -533,9 +546,9 @@ ARGS = parser.parse_args()
 if ARGS.verbose:
     logger.setLevel(logging.DEBUG)
 
-logger.debug(f"Welcome to {NAME} v{VERSION}!")
-logger.debug(f"Caching files in {CACHE_DIR}.")
-logger.debug(f"Using temporary directory {TEMPDIR}")
+logger.debug("Welcome to %s v%s!", NAME, VERSION)
+logger.debug("Caching files in %s.", CACHE_DIR)
+logger.debug("Using temporary directory %s", TEMPDIR)
 
 
 def main():
